import React from "react";
import { HeroBox } from "@components/HeroBox";
import type { INewsCategory } from "@interfaces/INews";
import { OverlayTag } from "@components/OverlayTag";

export interface HeroSectionProps {
  src: string;
  withGradientOnMobile?: boolean;
  children?: React.ReactNode;
  title?: string;
  description?: string;
  boxAlignment?: "left" | "right" | "center";
  categories?: INewsCategory[];
  transparentOnMobile?: boolean;
  imageTag?: string;
  className?: string;
  target?: string;
}

export const HeroSection: React.FC<HeroSectionProps> = ({
  src,
  withGradientOnMobile,
  children,
  title,
  description,
  boxAlignment,
  categories,
  transparentOnMobile,
  imageTag,
  className,
  target,
}) => {
  return (
    <section
      style={{ backgroundImage: `url(${src})` }}
      className={`relative w-full h-[35vh] sm:h-[50vh] md:h-[500px] xl:h-[60vh] xl:pt-12 bg-center bg-no-repeat bg-cover ${
        className || ""
      }`}
    >
      {imageTag && (
        <OverlayTag
          text={imageTag}
          className="absolute bottom-0 sm:bottom-6 right-0"
          variant="right"
        />
      )}
      {title && description && (
        <div className="container relative w-full h-full">
          <HeroBox
            title={title}
            description={description}
            categories={categories}
            selfAligned={boxAlignment}
            transparentOnMobile={transparentOnMobile}
            target={target}
          />
        </div>
      )}
      {children}
      {withGradientOnMobile && (
        <div className="block lg:hidden absolute bottom-0 z-10 w-full h-1/2 bg-gradient-to-b from-transparent to-[#313846]"></div>
      )}
    </section>
  );
};
